ContactManagerImpl class

Reads contacts and contact photos from the device.

Inheritance
  • Object
  • ContactManager
  • ContactManagerImpl

Constructors

ContactManagerImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContactPhoto(String id, ContactPhotoSuccessCallback onSuccess, ContactPhotoErrorCallback onError) Future<void>
Fetches a contact photo by contact identifier.
override
getPhoneContacts(ContactSuccessCallback onSuccess, ContactErrorCallback onError) Future<void>
Requests permission and returns phone contacts.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() Future<bool>
Requests read access to device contacts.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited